Engine
======

A wrapper library that integrates GeoEngine and MMLab libraries for GeoSpatial ML development.

Installation
------------

.. code:: shell

   pip install geolibs

License
-------

GPLv3

Documentation
-------------

View documentation ``here <https://engine.granular.ai/>``\ \_
